import { __assign } from './../../external/tslib/tslib.es6.js';
import React, { useState } from 'react';
import classnames from 'classnames';
import { useAutoPositioner } from '@highlight-ui/utils-hooks';
import { GroupedPortal } from '@highlight-ui/utils-portal-manager';
import { parseMetadata } from '@highlight-ui/utils-commons';
import { Icon } from '@highlight-ui/icon';
import { Typography } from '@highlight-ui/typography';
import InlineAlertPopover from './inline-alert-popover/InlineAlertPopver.js';
import statusToIconName from '../statusToIconName.js';
import styles from './InlineAlert.module.scss.js';
import normalizeStatus from '../normalizeStatus.js';

function InlineAlertWithRef(_a, ref) {
  var _b;

  var children = _a.children,
      metadata = _a.metadata,
      status = _a.status,
      iconColor = _a.iconColor,
      iconFamily = _a.iconFamily,
      iconName = _a.iconName,
      iconSize = _a.iconSize,
      iconClassName = _a.iconClassName,
      popoverContent = _a.popoverContent,
      _c = _a.popoverPlacement,
      popoverPlacement = _c === void 0 ? 'bottom-start' : _c;
  var normalizedStatus = normalizeStatus(status);
  var statusIconColor = "icon-" + normalizedStatus;
  var statusIconName = statusToIconName(normalizedStatus);

  var _d = useState(false),
      isPopoverVisible = _d[0],
      setPopoverVisibility = _d[1];

  var _e = useAutoPositioner({
    placement: popoverPlacement
  }),
      setReferenceElement = _e.setReferenceElement,
      setPopperElement = _e.setPopperElement,
      popperStyles = _e.styles.popper,
      attributes = _e.attributes;

  return /*#__PURE__*/React.createElement("div", __assign({
    ref: ref,
    className: styles.alertContainer
  }, parseMetadata(metadata)), /*#__PURE__*/React.createElement("div", {
    ref: setReferenceElement,
    className: classnames(styles.horizontalStack, (_b = {}, _b[styles.cursorPointer] = popoverContent, _b)),
    onClick: function () {
      if (isPopoverVisible) {
        return;
      }

      setPopoverVisibility(true);
    }
  }, /*#__PURE__*/React.createElement("span", {
    className: iconClassName
  }, /*#__PURE__*/React.createElement(Icon, {
    name: iconName !== null && iconName !== void 0 ? iconName : statusIconName,
    color: iconColor !== null && iconColor !== void 0 ? iconColor : statusIconColor,
    size: iconSize !== null && iconSize !== void 0 ? iconSize : 16,
    type: iconFamily !== null && iconFamily !== void 0 ? iconFamily : 'solid'
  })), children && /*#__PURE__*/React.createElement(Typography, {
    variant: "body-1",
    className: classnames(styles.supportText)
  }, children)), popoverContent && isPopoverVisible && /*#__PURE__*/React.createElement(GroupedPortal, null, /*#__PURE__*/React.createElement(InlineAlertPopover, __assign({
    closeCallback: function () {
      setPopoverVisibility(false);
    },
    ref: setPopperElement,
    style: popperStyles
  }, attributes.popper), popoverContent)));
}

InlineAlertWithRef.displayName = 'InlineAlert';
var InlineAlert = /*#__PURE__*/React.forwardRef(InlineAlertWithRef);
export { InlineAlertWithRef, InlineAlert as default };
//# sourceMappingURL=InlineAlert.js.map
